@@ -1,6 +1,8 @@
 #include "qmlapplicationviewer.h"
 #include "controller.h"
 #include "youtube.h"
+#include "dailymotion.h"
+#include "vimeo.h"
 #include "sharing.h"
 #include "downloadmanager.h"
 #include "folderlistmodel.h"
@@ -15,13 +17,12 @@
 
 int main(int argc, char *argv[])
 {
-#ifdef Q_WS_MAEMO_5
-    QApplication::setApplicationName(QString("FMRadio"));
-#endif
-
-    QApplication app(argc, argv);   
+    QApplication app(argc, argv);
+    app.setApplicationName(QString("cuteTube"));
     Controller ct;
     YouTube yt;
+    DailyMotion daily;
+    Vimeo vimeo;
 
     QStringList args = app.arguments();
     args.takeFirst();
@@ -39,11 +40,15 @@ int main(int argc, char *argv[])
         yt.setNetworkAccessManager(manager);
         dm.setNetworkAccessManager(manager);
         sh.setNetworkAccessManager(manager);
+        daily.setNetworkAccessManager(manager);
+        vimeo.setNetworkAccessManager(manager);
 
         context->setContextProperty("Controller", &ct);
         context->setContextProperty("DownloadManager", &dm);
         context->setContextProperty("YouTube", &yt);
         context->setContextProperty("Sharing", &sh);
+        context->setContextProperty("DailyMotion", &daily);
+        context->setContextProperty("Vimeo", &vimeo);
 
         qmlRegisterType<QDeclarativeFolderListModel>("Models",1,0,"FolderListModel");
 
@@ -76,16 +81,14 @@ int main(int argc, char *argv[])
 
         QString locale = ct.getLanguage();
         QString languagePath;
+        languagePath = viewer.engine()->baseUrl().toLocalFile().append("/qml/qmltube/i18n/qml_" + locale);
 #ifdef Q_WS_MAEMO_5
         languagePath = "/opt/usr/share/qmltube/qml/qmltube/i18n/qml_" + locale;
-#else
-        languagePath = viewer.engine()->baseUrl().toLocalFile().append("qml/qmltube/i18n/qml_" + locale);
 #endif
         QTranslator translator;
         if (translator.load(languagePath)) {
             app.installTranslator(&translator);
         }
-
         viewer.setMainQmlFile(QLatin1String("qml/qmltube/main.qml"));
         viewer.showFullScreen();
 
@@ -95,20 +98,37 @@ int main(int argc, char *argv[])
     else if (args.first() == ("--play")) {
         /* Get the video URL and play the video */
 
-        QString playerUrl = args.at(1);
-        QString videoId = playerUrl.split("v=").at(1).split("&").at(0);
-        QString quality = "hq";
-        if (args.length() > 2) {
-            if (args.at(2) == "m") {
-                quality = "mobile";
-            }
-        }
         ct.getMediaPlayerFromDB();
-        QObject::connect(&yt, SIGNAL(gotVideoUrl(QString)), &ct, SLOT(playVideo(QString)));
-        QObject::connect(&yt, SIGNAL(videoUrlError()), &app, SLOT(quit()));
         QObject::connect(&ct, SIGNAL(playbackStarted(QString)), &app, SLOT(quit()));
-        yt.setPlaybackQuality(quality);
-        yt.getVideoUrl(videoId);
+
+        QString playerUrl = args.at(1);
+        QString videoId;
+        if (playerUrl.contains("youtube")) {
+
+            QString quality = "hq";
+            if (args.length() > 2) {
+                if (args.at(2) == "m") {
+                    quality = "mobile";
+                }
+            }
+            videoId = playerUrl.split("v=").at(1).split("&").at(0);
+            yt.setPlaybackQuality(quality);
+            yt.getVideoUrl(videoId);
+            QObject::connect(&yt, SIGNAL(gotVideoUrl(QString)), &ct, SLOT(playVideo(QString)));
+            QObject::connect(&yt, SIGNAL(videoUrlError()), &app, SLOT(quit()));
+        }
+        else if (playerUrl.contains("dailymotion")) {
+            videoId = playerUrl.split("/").last();
+            daily.getVideoUrl(videoId);
+            QObject::connect(&daily, SIGNAL(gotVideoUrl(QString)), &ct, SLOT(playVideo(QString)));
+            QObject::connect(&daily, SIGNAL(videoUrlError()), &app, SLOT(quit()));
+        }
+        else if (playerUrl.contains("vimeo")) {
+            videoId = playerUrl.split("/").last();
+            vimeo.getVideoUrl(videoId);
+            QObject::connect(&vimeo, SIGNAL(gotVideoUrl(QString)), &ct, SLOT(playVideo(QString)));
+            QObject::connect(&vimeo, SIGNAL(videoUrlError()), &app, SLOT(quit()));
+        }
 
         return app.exec();
     }
